const path = require("path");
const ACTIONS = {
  GET_DEFAULT_EXTENSIONS: "GET_DEFAULT_EXTENSIONS",
  SET_OPTIONS: "SET_OPTIONS",
  TRANSFORM: "TRANSFORM",
  TRANSFORM_SYNC: "TRANSFORM_SYNC"
};
class Client {
  #send;
  constructor(send) {
    this.#send = send;
  }
  #eCache;
  getDefaultExtensions() {
    return this.#eCache ??= this.#send(ACTIONS.GET_DEFAULT_EXTENSIONS, undefined);
  }
  setOptions(options) {
    return this.#send(ACTIONS.SET_OPTIONS, options);
  }
  transform(code, filename) {
    return this.#send(ACTIONS.TRANSFORM, {
      code,
      filename
    });
  }
}
exports.WorkerClient = class WorkerClient extends Client {
  static get #worker_threads() {
    return require("worker_threads");
  }
  static get #markInRegisterWorker() {
    return require("./is-in-register-worker.js").markInRegisterWorker;
  }
  #worker = new WorkerClient.#worker_threads.Worker(path.resolve(__dirname, "./worker/index.js"), {
    env: WorkerClient.#markInRegisterWorker(process.env)
  });
  #signal = new Int32Array(new SharedArrayBuffer(4));
  constructor() {
    super((action, payload) => {
      this.#signal[0] = 0;
      const subChannel = new WorkerClient.#worker_threads.MessageChannel();
      this.#worker.postMessage({
        signal: this.#signal,
        port: subChannel.port1,
        action,
        payload
      }, [subChannel.port1]);
      Atomics.wait(this.#signal, 0, 0);
      const {
        message
      } = WorkerClient.#worker_threads.receiveMessageOnPort(subChannel.port2);
      if (message.error) throw Object.assign(message.error, message.errorData);else return message.result;
    });
    this.#worker.unref();
  }
};
;

//# sourceMappingURL=worker-client.js.map
